# frozen_string_literal: true

require_relative 'helper'

module Jekyll
  module ActivityPub
    # Represents a Create activity
    class Create
      include Helper

      attr_reader :data

      # Initialize with default data
      #
      # @param :site [Jekyll::Site]
      # @param :actor [Jekyll::ActivityPub::Actor]
      # @param :object [Jekyll::ActivityPub::Activity]
      def initialize(site, actor, object)
        @context = StubContext.new(registers: { site: site })

        @data = {
          '@context' => 'https://www.w3.org/ns/activitystreams',
          'type' => 'Create',
          'actor' => absolute_url(actor.url),
          'published' => object.data['published'],
          'to' => object.data['to'],
          'cc' => object.data['cc'],
          'object' => absolute_url(object.url),
          'inReplyTo' => object.data['in_reply_to']
        }

        trigger_hooks :post_init
      end
    end
  end
end
